@@ -6,7 +6,7 @@
 #SBATCH --time=04:00:00                  # Time limit hrs:min:sec
 #SBATCH --output="{{ qspool::job_log_path }}/a=log+{{ qspool::qspool_job_name }}+slurm_job_id=%a+ext=.txt"
 
-__version__ = "0.2.1"
+__version__ = "0.2.3"
 __author__ = "Matthew Andres moreno"
 
 import argparse
@@ -166,6 +166,7 @@ def make_qspool_job_name(
 
 
 if __name__ == "__main__":
+    logging.info(f"__version__={__version__}")
     start_time = time.time()
     logging.info(f"start_time={start_time}")
 
@@ -329,7 +330,7 @@ if __name__ == "__main__":
             )
 
             continuation_job_script_file.write(
-                continuation_job_script_contents
+                continuation_job_script_contents.strip()
             )
             continuation_job_script_file.file.close()
             os.chmod(continuation_job_script_file.name, 0o775)
